@@ -3,12 +3,12 @@ package Cwd::Guard;
 use strict;
 use warnings;
 use Cwd qw/getcwd/;
+use autodie qw/chdir/;
 use parent 'Exporter';
 
 our @EXPORT_OK = qw/cwd_guard/;
-our $Error;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub cwd_guard {
     my $dir = shift;
@@ -22,9 +22,7 @@ sub new {
     my $callback = sub {
         chdir $cwd;
     };
-    my $result = defined $dir ? chdir($dir) : chdir();
-    $Error = $!;
-    return unless $result;
+    defined $dir ? chdir($dir) : chdir();
     bless $callback, $class;
 }
 
@@ -47,7 +45,7 @@ Cwd::Guard - Temporary changing working directory (chdir)
 
   my $dir = getcwd;
   MYBLOCK: {
-      my $guard = cwd_guard('/tmp/xxxxx') or die "failed chdir: $Cwd::Guard::Error";
+      my $guard = cwd_guard('/tmp/xxxxx');
       # chdir to /tmp/xxxxx
   }
   # back to $dir
@@ -64,7 +62,7 @@ CORE::chdir Cwd:: Guard can change the current directory (chdir) using a limited
 =item cwd_guard($dir);
 
 chdir to $dir and returns Cwd::Guard object. return to current working directory, if this object destroyed.
-if failed to chdir, cwd_guard return undefined value. You can get error messages with $Gwd::Guard::Error.
+if failed to chdir, Cwd::Guard die immediately. 
 
 =back
 
@@ -78,6 +76,8 @@ L<File::chdir>, L<File::pushd>
 
 =head1 LICENSE
 
+Copyright (C) Masahiro Nagano
+
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
